#! /bin/sh

#
#	install-cricket.sh - copy cricket into place
#

#
# You need the following packages before you can run Cricket:
#
#	lang/perl			>= 5.6.1nb2
#	devel/p5-perl-headers		(implicitly the current OS version)
#	databases/rrdtool		>= 1.0.33 (1.0.40 now!)
#	security/p5-Digest-MD5		>= 2.20
#	net/p5-SNMP_Session		>= 0.94
#	time/p5-TimeDate		>= 1.10
#
# they say that to get http-performance to work for HTTPS:
#
# perl -MCPAN -eshell  
# cpan> install LWP::Protocol
# cpan> install Crypt::SSLeay
# cpan> quit

PREFIX=${PREFIX:-"/usr/local"}
export PREFIX		# used by util/relocate-perl

PKG_SYSCONFDIR=${PKG_SYSCONFDIR:-/usr/local/etc}
export PKG_SYSCONFDIR	# used by util/relocate-perl

PERL5=${PERL5:-"/usr/local/bin/perl"}
export PERL5		# used by util/relocate-perl

CHOME="${PREFIX}/cricket"

CUSER=${CRICKET_USER:-"cricket"}
CGROUP=${CRICKET_GROUP:-"cricket"}
CADMIN=${CRICKET_ADMIN:-"crickadm"}
CADMGRP=${CRICKADM_GROUP:-"crickadm"}

set -e

install -d -o root -g wheel -m 0755 $CHOME

install -d -o root -g wheel -m 0755 $CHOME/bin $CHOME/etc $CHOME/lib $CHOME/libexec $CHOME/util
install -d -o $CADMIN -g $CADMGRP -m 0775 $CHOME/public_html
install -d -o root -g wheel -m 0755 $CHOME/public_html/doc
install -d -o $CADMIN -g $CADMGRP -m 0775 $CHOME/cricket-config $CHOME/public_html/images
install -d -o $CUSER -g $CGROUP -m 0775 $CHOME/cricket-data $CHOME/cricket-logs

install -c -o root -g wheel -m 0444 CHANGES $CHOME/public_html/doc/CHANGES
install -c -o root -g wheel -m 0444 COPYING $CHOME/public_html/doc/COPYING
install -c -o root -g wheel -m 0444 README $CHOME/public_html/doc/README
install -c -o root -g wheel -m 0444 THANKS $CHOME/public_html/doc/THANKS
install -c -o root -g wheel -m 0444 TODO $CHOME/public_html/doc/TODO

install -c -o root -g wheel -m 0444 VERSION $CHOME/etc

install -c -o $CADMIN -g $CADMGRP -m 0664 subtree-sets $CHOME/etc

install -c -o root -g wheel -m 0555 compile $CHOME/bin
install -c -o root -g wheel -m 0555 collector $CHOME/bin
install -c -o root -g wheel -m 0555 collect-subtrees $CHOME/bin

install -c -o root -g wheel -m 0555 grapher.cgi $CHOME/libexec
install -c -o root -g wheel -m 0555 mini-graph.cgi $CHOME/libexec

install -c -o $CADMIN -g $CADMGRP -m 0444 public_html/index.html $CHOME/public_html

find lib ! -type d -print | egrep -v '/CVS|/\.#|/\.cvsignore' | pax -rw $CHOME
find util ! -type d -print | egrep -v '/CVS|/\.#|/\.cvsignore' | pax -rw $CHOME
find sample-config ! -type d -print | egrep -v '/CVS|/\.#|/\.cvsignore' | pax -rw $CHOME

find images ! -type d -print | egrep -v '/CVS|/\.#|/\.cvsignore' | pax -rw $CHOME/public_html/
find doc ! -type d -print | egrep -v '/CVS|/\.#|/\.cvsignore' | pax -rw $CHOME/public_html/

install -d -o root -g wheel -m 0755 ${PREFIX}/share/examples
sed -e "s+/usr/local/cricket/+${CHOME}/+g" < cricket-conf.pl.sample > ${PREFIX}/share/examples/cricket-conf.pl
chown root:wheel ${PREFIX}/share/examples/cricket-conf.pl
chmod 0444 ${PREFIX}/share/examples/cricket-conf.pl

if [ ! -f ${PKG_SYSCONFDIR}/cricket-conf.pl ] ; then
	echo "NOTICE:  you need to copy and then edit the configuration file:"
	echo "	cp ${PREFIX}/share/examples/cricket-conf.pl ${PKG_SYSCONFDIR}/cricket-conf.pl"
fi

if [ ! -f $CHOME/cricket-config/Defaults ] ; then
	( cd $CHOME/sample-config ; pax -rw . ../cricket-config )
	chown -R ${CADMIN}:${CADMGRP} $CHOME/cricket-config
	chmod -R ug+w $CHOME/cricket-config
else
	# cater to manual installations....
	echo "NOTICE:  not overwriting existing $CHOME/cricket-config/"
fi

cd $CHOME && ${SH} util/relocate-perl

exit $?
